hostedclusterpackages

package
v1.19.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 29, 2026 License: Apache-2.0 Imports: 22 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExtractPackageTemplateFields

func ExtractPackageTemplateFields(
	hcpkg *unstructured.Unstructured,
) (*corev1alpha1acs.PackageTemplateSpecApplyConfiguration, error)

ExtractPackageTemplateFields extracts specified fields from the given HostedClusterPackage's .spec.template by remarshaling them into an applyconfiguration. This ensures that only user-specified fields get sent to the API and no go defaulting on unspecified fields takes place. Defaulting for example always send intents with .spec.paused set to false, which prevents users from overriding the field with their own intents.

Types

type HostedClusterPackageController

type HostedClusterPackageController struct {
	// contains filtered or unexported fields
}

func NewHostedClusterPackageController

func NewHostedClusterPackageController(
	c client.Client, log logr.Logger, scheme *runtime.Scheme,
) *HostedClusterPackageController

func (*HostedClusterPackageController) Reconcile

func (*HostedClusterPackageController) SetupWithManager

func (c *HostedClusterPackageController) SetupWithManager(mgr ctrl.Manager) error

Jump to