Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExtractPackageTemplateFields ¶
func ExtractPackageTemplateFields( hcpkg *unstructured.Unstructured, ) (*corev1alpha1acs.PackageTemplateSpecApplyConfiguration, error)
ExtractPackageTemplateFields extracts specified fields from the given HostedClusterPackage's .spec.template by remarshaling them into an applyconfiguration. This ensures that only user-specified fields get sent to the API and no go defaulting on unspecified fields takes place. Defaulting for example always send intents with .spec.paused set to false, which prevents users from overriding the field with their own intents.
Types ¶
type HostedClusterPackageController ¶
type HostedClusterPackageController struct {
// contains filtered or unexported fields
}
func (*HostedClusterPackageController) SetupWithManager ¶
func (c *HostedClusterPackageController) SetupWithManager(mgr ctrl.Manager) error
Click to show internal directories.
Click to hide internal directories.